<?php
/* $Id: greek-utf-8.inc.php,v 2.66 2005/03/30 19:22:01 lem9 Exp $ */

/* Translated by Kyriakos Xagoraris <theremon at users.sourceforge.net> */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'tahoma, verdana, helvetica, geneva, sans-serif';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Κυρ', 'Δευ', 'Τρι', 'Τετ', 'Πεμ', 'Παρ', 'Σαβ');
$month = array('Ιαν', 'Φεβ', 'Μάρ', 'Απρ', 'Μάι', 'Ιούν', 'Ιούλ', 'Αυγ', 'Σεπ', 'Οκτ', 'Νοε', 'Δεκ');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y, στις %I:%M %p';

// To Arrange

$timespanfmt = '%s μέρες, %s ώρες, %s λεπτά and %s δευτερόλεπτα'; 

$strAPrimaryKey = 'Ένα πρωτεύον κλειδί προστέθηκε στο %s';
$strAbortedClients = 'Ακυρωμένες συνδέσεις'; 
$strAbsolutePathToDocSqlDir = 'Παρακαλώ εισάγετε την απόλυτη διαδρομή στον διακομιστή για τον υποκατάλογο του docSQL';  
$strAccessDenied = '\'Αρνηση Πρόσβασης';
$strAccessDeniedExplanation = 'Το phpMyAdmin προσπάθησε να συνδεθεί με τον διακομιστή MySQL αλλά ο διακομιστής απέριψε τη σύνδεση. Θα πρέπει να ελέγξετε την διεύθυνση, το όνομα χρήστη και τον κωδικό πρόσβασης στο αρχείο ρυθμίσεων config.inc.php και να βεβαιωθείτε ότι αντιστοιχούν σε αυτά που σας έχει δώσει ο διαχειρηστής του διακομιστή MySQL.'; 
$strAction = 'Ενέργεια';
$strAddAutoIncrement = 'Προσθήκη τιμής AUTO_INCREMENT';  
$strAddDeleteColumn = 'Προσθήκη/Αφαίρεση Στήλης Πεδίου';
$strAddDeleteRow = 'Προσθήκη/Αφαίρεση Γραμμής Κριτηρίων';
$strAddDropDatabase = 'Προσθήκη DROP DATABASE';
$strAddIntoComments = 'Προσθήκη στα σχόλια';
$strAddNewField = 'Προσθήκη νέου Πεδίου';
$strAddPrivilegesOnDb = 'Προσθήκη προνομίων στην ακόλουθη βάση δεδομένων'; 
$strAddPrivilegesOnTbl = 'Προσθήκη δεδομένων στον ακόλουθο πίνακα'; 
$strAddSearchConditions = 'Προσθήκη νέου όρου (σώμα της "where" πρότασης):';
$strAddToIndex = 'Προσθήκη στο ευρετήριο &nbsp;%s&nbsp;κολώνας(ων)';
$strAddUser = 'Προσθήκη νέου Χρήστη';
$strAddUserMessage = 'Προσθέσατε ένα νέο χρήστη.';
$strAddedColumnComment = 'Το σχόλιο της στήλης προστέθηκε';  
$strAddedColumnRelation = 'Η συσχέτιση της στήλης προστέθηκε';  
$strAdministration = 'Διαχείριση'; 
$strAffectedRows = 'Επηρρεαζόμενες εγγραφές:';
$strAfter = 'Μετά το %s';
$strAfterInsertBack = 'Επιστροφή';
$strAfterInsertNewInsert = 'Εισαγωγή νέας εγγραφής';
$strAll = 'Όλα';
$strAllTableSameWidth = 'εμφάνιση όλων των πινάκων με το ίδιο πλάτος;';
$strAlterOrderBy = 'Αλλαγή ταξινόμησης Πίνακα κατά';
$strAnIndex = 'Ένα ευρετήριο προστέθηκε στο %s';
$strAnalyzeTable = 'Ανάλυση Πίνακα';
$strAnd = 'Και';
$strAny = 'Οποιοδήποτε';
$strAnyHost = 'Οποιοδήποτε Σύστημα';
$strAnyUser = 'Οποιοσδήποτε Χρήστης';
$strArabic = 'Αραβικά';  
$strArmenian = 'Αρμενικά';  
$strAscending = 'Αύξουσα';
$strAtBeginningOfTable = 'Στην αρχή του Πίνακα';
$strAtEndOfTable = 'Στο τέλος του Πίνακα';
$strAttr = 'Χαρακτηριστικά';
$strAutodetect = 'Αυτόματη ανίχνευση';  
$strAutomaticLayout = 'Αυτόματη διάταξη';  

$strBack = 'Επιστροφή';
$strBaltic = 'Βαλτικής';  
$strBeginCut = 'BEGIN CUT';  
$strBeginRaw = 'BEGIN RAW';  
$strBinary = 'Δυαδικό';
$strBinaryDoNotEdit = 'Δυαδικό - χωρίς δυνατότητα επεξεργασίας';
$strBookmarkDeleted = 'Η ετικέτα διεγράφη.';
$strBookmarkLabel = 'Τίτλος';
$strBookmarkQuery = 'Αποθηκευμένο επερώτημα SQL';
$strBookmarkThis = 'Αποθήκευση αυτού του επερωτήματος SQL';
$strBookmarkView = 'Μόνο ανάγνωση';
$strBrowse = 'Περιήγηση';
$strBulgarian = 'Βουλγαρικά';  
$strBzError = 'Το phpMyAdmin δεν μπόρεσε να συμπιέσει το αρχείο εξόδου λόγω προβλήματος στην επέκταση Bz2 αυτής της έκδοσης php. Προτείνεται να ορίσετε την τιμή της μεταβλητής <code>$cfg[\'BZipDump\']</code> στο αρχείο ρυθμίσεων του phpMyAdmin σε <code>FALSE</code>. Εάν θέλετε να χρησιμοποιήσετε λειτουργίες συμπίεσης τύπου Bz2, θα πρέπει να αναβαθμίσετε την php σε μεταγενέστερη έκδοση. Δείτε την αναφορά προβλήματος php %s για περισσότερες λεπτομέρειες.'; 
$strBzip = 'συμπίεση «bzip»';

$strCSVOptions = 'Επιλογές CSV';
$strCannotLogin = 'Δεν ήταν δυνατή η σύνδεση με τον διακομιστή MySQL';  
$strCantLoad = 'δεν ήταν δυνατή η φόρτωση της επέκτασης %s ,<br />παρακαλώ ελέγξτε τις ρυθμίσεις της PHP';  
$strCantLoadRecodeIconv = 'Δεν είναι δυνατή η φόρτωση της επέκτασης iconv ή recode που χρειάζεται για την μετατροπή του σετ χαρακτήρων. Ρυθμίστε την php να επιτρέπει την χρήση αυτών των επεκτάσεων ή απανεργοποιήστε την μετατροπή χαρακτήρων στο phpMyAdmin.'; 
$strCantRenameIdxToPrimary = 'Η μετονομασία του ευρετηρίου σε PRIMARY σε είναι εφικτή!';
$strCantUseRecodeIconv = 'Δεν είναι δυνατή η χρήση της επέκτασης iconv ούτε της libiconv ούτε της ρουτίνας recode_string, ενώ η επέκταση έχει φορτωθεί. Ελέξτε τις ρυθμίσεις της php.'; 
$strCardinality = 'Μοναδικότητα';
$strCarriage = 'Χαρακτήρας επιστροφής: \\r';
$strCentralEuropean = 'Κεντρικής Ευρώπης';  
$strChange = 'Αλλαγή';
$strChangeCopyMode = 'Δημιουργία νέα χρήστη με τα ίδια προνόμια και ...';  
$strChangeCopyModeCopy = '... διατήρηση του παλιού χρήστη.';  
$strChangeCopyModeDeleteAndReload = ' ... διαγραφή του παλιού χρήστη από τους πίνακες χρηστών και επαναφόρτωση των προνομίων.';  
$strChangeCopyModeJustDelete = ' ... διαγραφή του παλιού χρήστη από τους πίνακες χρηστών.';  
$strChangeCopyModeRevoke = ' ... ανάκληση των προνομίων του παλιού χρήστη και διαγραφή του.';  
$strChangeCopyUser = 'Αλλαγή Στοιχείων Πρόσβασης / Αντιγραφή Χρήστη';  
$strChangeDisplay = 'Επιλέξτε πεδίο για εμφάνιση';
$strChangePassword = 'Αλλαγή κωδικού πρόσβασης';
$strCharset = 'Σετ χαρακτήρων';  
$strCharsetOfFile = 'Σετ χαρακτήρων του αρχείου:'; 
$strCharsets = 'Σετ χαρακτήρων';  
$strCheckAll = 'Επιλογή όλων';
$strCheckPrivs = 'Έλεγχος Προνομίων';  
$strCheckPrivsLong = 'Έλεγχος προνομίων για τη βάση &quot;%s&quot;.';  
$strCheckTable = 'Έλεγχος πίνακα';
$strChoosePage = 'Παρακαλώ επιλέξτε σελίδα για αλλαγή';  
$strColComFeat = 'Εμφάνιση σχολίων πεδίων';
$strColumnNames = 'Ονόματα στηλών';
$strColumnPrivileges = 'Προνόμια πεδίων'; 
$strCommand = 'Εντολή'; 
$strComments = 'Σχόλια';  
$strCompleteInserts = 'Ολοκληρωμένες εντολές «Insert»';
$strCompression = 'Συμπίεση'; 
$strConfigFileError = 'Το phpMyAdmin δεν μπόρεσε να διαβάσει το αρχείο ρυθμίσεων!<br />Αυτό μπορεί να συμβεί εάν η php βρει κάποιο λάθος στο αρχείο ή εάν η php δεν μπορεί να βρει το αρχείο.<br />Παρακαλώ καλέστε το αρχείο ρυθμίσεων απ\' ευθείας χρησιμοποιώντας το ακόλουθο link και διαβάστε τα μυνήματα λάθους που θα επιστρέψει η php. Στις περισσότερες περιπτώσεις κάπου λείπουν εισαγωγικά (") ή ερωτιματικά (;).<br />Εάν η php επιστρέψει μια λευκή σελίδα, όλα είναι σωστά.'; 
$strConfigureTableCoord = 'Παρακαλώ ορίστε τις συντεταγμένες για τον πίνακα %s';  
$strConnections = 'Συνδέσεις'; 
$strCookiesRequired = 'Από αυτό το σημείο πρέπει να έχετε ενεργοποιημένα cookies.';
$strCopyTable = 'Αντιγραφή πίνακα σε (βάση<b>.</b>πίνακας):';
$strCopyTableOK = 'Ο Πίνακας %s αντιγράφηκε στο %s.';
$strCopyTableSameNames = 'Δεν είναι δυνατή η αντιγραφή του πίνακα στον εαυτό του!';  
$strCouldNotKill = 'Το phpMyAdmin δεν μπόρεσε να διακόψει τη λειτουργία %s. Μπορεί να έχει ήδη σταματήσει.'; 
$strCreate = 'Δημιουργία';
$strCreateIndex = 'Δημιουργία ευρετηρίου σε &nbsp;%s&nbsp;πεδία';
$strCreateIndexTopic = 'Δημιουργία νέου ευρετηρίου';
$strCreateNewDatabase = 'Δημιουργία νέας βάσης';
$strCreateNewTable = 'Δημιουργία νέου πίνακα στη βάση %s';
$strCreatePage = 'Δημιουργία νέας σελίδας';  
$strCreatePdfFeat = 'Δημιουργία αρχείων PDF';
$strCriteria = 'Κριτήρια';
$strCroatian = 'Κροατικά';  
$strCyrillic = 'Κυριλλικά';  
$strCzech = 'Τσεχικά';  

$strDBComment = 'Σχόλιο βάσης: ';
$strDBGContext = 'Context';  
$strDBGContextID = 'Context ID';  
$strDBGHits = 'Hits';  
$strDBGLine = 'Γραμμή';  
$strDBGMaxTimeMs = 'Μεγ. χρόνος, ms';  
$strDBGMinTimeMs = 'Ελαχ. χρόνος, ms';  
$strDBGModule = 'Module';  
$strDBGTimePerHitMs = 'Χρόνος/Hit, ms';  
$strDBGTotalTimeMs = 'Συνολ. χρόνου, ms';  
$strDanish = 'Δανικά';  
$strData = 'Δεδομένα';
$strDataDict = 'Λεξικό δεδομένων';  
$strDataOnly = 'Μόνο τα δεδομένα';
$strDatabase = 'Βάση';
$strDatabaseExportOptions = 'Επιλογές εξαγωγής βάσης δεδομένων';
$strDatabaseHasBeenDropped = 'Η βάση δεδομένων %s διεγράφη.';
$strDatabaseNoTable = 'Αυτή η βάση δεν περιέχει πίνακες!';
$strDatabases = 'Βάσεις Δεδομένων';
$strDatabasesDropped = '%s βάσεις δεδομένων διεγράφησαν επιτυχώς.';  
$strDatabasesStats = 'Στατιστικά βάσης';
$strDatabasesStatsDisable = 'Απενεργοποίηση Στατιστικών';  
$strDatabasesStatsEnable = 'Ενεργοποίηση Στατιστικών';  
$strDatabasesStatsHeavyTraffic = 'Σημείωση: Η ενεργοποίηση στατιστικών μπορεί να προκαλέσει μεγάλη μεταφορά δεδομένων μεταξύ του διακομιστή διαδικτύου και του διακομιστή MySQL.';  
$strDbPrivileges = 'Προνόμια βάσης δεδομένων'; 
$strDbSpecific = 'Χρήστης Βάσης';  
$strDefault = 'Προκαθορισμένο';
$strDefaultValueHelp = 'Για προκαθορισμένες τιμές, παρακαλώ εισάγετε μία τιμή, χωρίς χαρακτήρες διαφυγής ή εισαγωγικά, χρησιμοποιώντας τη μορφή: a';  
$strDelOld = 'Η τρέχουσα σελίδα έχει αναφορές σε πίνακες που δεν υπάρχουν πια. Θέλετε να διαγραφές αυτές οι αναφορές;';  
$strDelete = 'Διαγραφή';
$strDeleteAndFlush = 'Διαγραφή των χρηστών και επαναφόρτωση των προνομίων.'; 
$strDeleteAndFlushDescr = 'Αυτός είναι ο πιο "καθαρός" τρόπος, αλλά η επαναφόρτωση των προνομίων μπορεί να καθυστερήσει.'; 
$strDeleted = 'Η Εγγραφή έχει διαγραφεί';
$strDeletedRows = 'Διαγραμμένες Εγγραφές:';
$strDeleting = 'Διαγραφή %s'; 
$strDescending = 'Φθίνουσα';
$strDescription = 'Περιγραφή';  
$strDictionary = 'λεξικό';  
$strDisabled = 'Απενεργοποιημένο';
$strDisplayFeat = 'Λειτουργίες εμφάνισης';
$strDisplayOrder = 'Σειρά εμφάνισης:';
$strDisplayPDF = 'Εμφάνιση σχήματος PDF';  
$strDoAQuery = 'Εκτέλεσε ένα «επερώτημα κατά παράδειγμα» (χαρακτήρας μπαλαντέρ "%")';
$strDoYouReally = 'Θέλετε να εκτελέσετε την εντολή';
$strDocu = 'Τεκμηρίωση';
$strDrop = 'Διαγραφή';
$strDropSelectedDatabases = 'Διαγραφή επιλεγμένων βάσεων δεδομένων';  
$strDropUsersDb = 'Διαγραφή βάσεων δεδομένων που έχουν ίδια ονόματα με χρήστες.'; 
$strDumpSaved = 'Το αρχείο εξόδου αποθηκεύτηκε ως %s.';  
$strDumpXRows = 'Εμφάνιση %s εγγραφών ξεκινώντας από την εγγραφή %s.'; 
$strDumpingData = '\'Αδειασμα δεδομένων του πίνακα';
$strDynamic = 'δυναμικά';

$strEdit = 'Επεξεργασία';
$strEditPDFPages = 'Αλλαγή σελίδων PDF';  
$strEditPrivileges = 'Επεξεργασία Προνομίων';
$strEffective = 'Αποτελεσματικός';
$strEmpty = '\'Αδειασμα';
$strEmptyResultSet = 'Η MySQL επέστρεψε ένα άδειο σύνολο αποτελεσμάτων (π.χ. καμμία εγγραφή).';
$strEnabled = 'Ενεργοποιημένο';
$strEnd = 'Τέλος';
$strEndCut = 'END CUT';  
$strEndRaw = 'END RAW';  
$strEnglish = 'Αγγλικά';  
$strEnglishPrivileges = ' Σημείωση: Τα ονόματα προνομίων της MySQL εκφράζονται στα Αγγλικά ';
$strError = 'λάθος';
$strEstonian = 'Εσθονικά';  
$strExcelOptions = 'Επιλογές Excel';  
$strExecuteBookmarked = 'Εκτέλεση αποθηκευμένου επερωτήματος';  
$strExplain = 'Ανάλυση SQL';  
$strExport = 'Εξαγωγή';  
$strExtendedInserts = 'Εκτεταμένες εντολές «Insert»';
$strExtra = 'Πρόσθετα';

$strFailedAttempts = 'Αποτυχημένες προσπάθειες'; 
$strField = 'Πεδίο';
$strFieldHasBeenDropped = 'Το πεδίο %s διεγράφη';
$strFields = 'Πεδία';
$strFieldsEmpty = ' Η απαρίθμηση των πεδίων είναι κενή! ';
$strFieldsEnclosedBy = 'Πεδία που περικλείονται σε';
$strFieldsEscapedBy = 'Τα πεδία χρησιμοποιούν το χαρακτήρα διαφυγής ';
$strFieldsTerminatedBy = 'Πεδία που τελειώνουν σε';
$strFileAlreadyExists = 'Το αρχείο %s υπάρχει ήδη στον διακομιστή. Επιλέξτε διαφορετικό όνομα αρχείου ή ενεργοποιήστε την επιλογή αντικατάστασης.';  
$strFileCouldNotBeRead = 'Δεν ήταν δυνατή η ανάγνωση του αρχείου';  
$strFileNameTemplate = 'Μορφή ονόματος αρχείου';
$strFileNameTemplateHelp = 'Χρησιμοποιήστε __DB__ για όνομα βάσης, __TABLE__ για όνομα πεδίου και %sοποιαδήποτε επιλογή strftime%s για ορισμό ώρας. Η επέκταση θα προστεθεί αυτόματα. Οποιοδήποτε άλλο κείμενο θα διατηρηθεί.';
$strFileNameTemplateRemember = 'αποθήκευση μορφής';
$strFixed = 'προκαθορισμένου μήκους';
$strFlushPrivilegesNote = 'Σημείωση: Το phpMyAdmin διαβάζει τα προνόμια των χρηστών απ\' ευθείεας από τους πίνακες προνομίων της MySQL. Το περιεχόμενο αυτών των πινάκων μπορεί να διαφέρει από τα προνόμια που χρησιμοποιεί ο διακομιστής εάν έχουν γίνει αλλαγές χειροκίνητα. Σε αυτήν την περίπτωση, θα πρέπει να %sεπαναφορτώσετε τα προνόμια%s πριν συνεχίσετε.'; 
$strFlushTable = 'Εκκαθάριση ("FLUSH") πίνακα';
$strFormEmpty = 'Ελλειπής τιμή στο πεδίο !';
$strFormat = 'Μορφοποίηση';
$strFullText = 'Πλήρη κείμενα';
$strFunction = 'Έλεγχος';

$strGenBy = 'Δημιουργήθηκε από:'; 
$strGenTime = 'Χρόνος δημιουργίας';
$strGeneralRelationFeat = 'Γενικές λειτουργίες συσχέτισης';
$strGerman = 'Γερμανικά';  
$strGlobal = 'Γενικός';  
$strGlobalPrivileges = 'Γενικά προνόμια'; 
$strGlobalValue = 'Γενική τιμή'; 
$strGo = 'Εκτέλεση';
$strGrantOption = 'Χορήγηση'; // Grant
$strGreek = 'Ελληνικά';  
$strGzip = 'συμπίεση «gzip»';

$strHasBeenAltered = 'έχει αλλαχθεί.';
$strHasBeenCreated = 'έχει δημιουργηθεί.';
$strHaveToShow = 'Πρέπει να επιλέξετε τουλάχιστον μία στήλη για εμφάνιση';  
$strHebrew = 'Εβραϊκά';  
$strHome = 'Κεντρική σελίδα';
$strHomepageOfficial = 'Επίσημη σελίδα του phpMyAdmin';
$strHost = 'Σύστημα';
$strHostEmpty = 'Το όνομα του Συστήματος είναι κενό!';
$strHungarian = 'Ουγγρικά';  

$strId = 'ID'; 
$strIdxFulltext = 'Πλήρες κείμενο';
$strIfYouWish = 'Αν ενδιαφέρεστε να φορτώσετε μόνο μερικές απο τις στήλες του πίνακα, καθορίστε μία λίστα πεδίων διαχωρισμένα με κόμμα.';
$strIgnore = 'Παράληψη';
$strIgnoringFile = 'Παράκαμψη του αρχείου %s';  
$strImportDocSQL = 'Εισαγωγή αρχείων docSQL';  
$strImportFiles = 'Εισαγωγή αρχείων';  
$strImportFinished = 'Η εισαγωγή τελείωσε';  
$strInUse = 'σε χρήση';
$strIndex = 'Ευρετήριο';
$strIndexHasBeenDropped = 'Το ευρετήριο %s διεγράφη';
$strIndexName = 'Όνομα ευρετηρίου&nbsp;:';
$strIndexType = 'Τύπος ευρετηρίου&nbsp;:';
$strIndexes = 'Ευρετήρια';
$strInnodbStat = 'Κατάσταση InnoDB';  
$strInsecureMySQL = 'Το αρχείο ρυθμίσεών σας περιέχει ρυθμίσεις (χρήστης root χωρίς κωδικό πρόσβασης) που αντιστοιχούν στον εξ\' ορισμού λογαριασμό χρήστη MySQL. Ο διακομιστής MySQL σας που τρέχει με αυτή τη ρύθμιση, είναι ανοιχτός σε επιθέσεις και θα πρέπει να διορθώσετε το πρόβλημα.';  
$strInsert = 'Εισαγωγή';
$strInsertAsNewRow = 'Εισαγωγή ως νέα εγγραφές';
$strInsertNewRow = 'Εισαγωγή νέας εγγραφής';
$strInsertTextfiles = 'Εισαγωγή αρχείου κειμένου στον πίνακα';
$strInsertedRowId = 'id εισαγμένης εγγραφής:';  
$strInsertedRows = 'Εισαγόμενες εγγραφές:';
$strInstructions = 'Οδηγίες';

$strJapanese = 'Ιαπωνικά';  
$strJumpToDB = 'Μεταπήδηση στην βάση &quot;%s&quot;.';  
$strJustDelete = 'Απλή διαγραφή των χρηστών από τους πίνακες προνομίων.'; 
$strJustDeleteDescr = 'Οι &quot;διεγραμμένοι&quot; χρήστες θα συνεχίσουν να έχουν πρόσβαση στον διακομιστή μέχρις ότου να επαναφορτωθούν οι πίνακες προνομίων.'; 

$strKeepPass = 'Διατήρηση κωδικού πρόσβασης';
$strKeyname = 'Όνομα κλειδιού';
$strKill = 'Τερματισμός';
$strKorean = 'Κορεατικά';  

$strLaTeX = 'LaTeX';  
$strLaTeXOptions = 'Επιλογές LaTeX';  
$strLandscape = 'Οριζόντια διάταξη';  
$strLengthSet = 'Μήκος/Τιμές*';
$strLimitNumRows = 'Εγγραφές ανά σελίδα';
$strLineFeed = 'Χαρακτήρας προώθησης γραμμής: \\n';
$strLinesTerminatedBy = 'Γραμμές που τελειώνουν σε';
$strLinkNotFound = 'Δεν βρέθηκε η σύνδεση';  
$strLinksTo = 'Σύνδεση με';  
$strLithuanian = 'Λιθουανικά';  
$strLoadExplanation = 'Η καλύτερη μέθοδος είναι ενεργοποιημένη εξ\' ορισμού, αλλά μπορείτε να την αλλάξετε αν αποτύχει.';  
$strLoadMethod = 'Μέθοδος LOAD';  
$strLocalhost = 'Τοπικό';
$strLocationTextfile = 'Τοποθεσία του αρχείου κειμένου';
$strLogPassword = 'Κωδικός πρόσβασης:';
$strLogUsername = 'Όνομα χρήστη:';
$strLogin = 'Σύνδεση';
$strLoginInformation = 'Πληροφορίες Σύνδεσης'; 
$strLogout = 'Αποσύνδεση';

$strMIME_MIMEtype = 'Τύπος MIME';
$strMIME_available_mime = 'Διαθέσιμοι τύποι MIME';
$strMIME_available_transform = 'Διαθέσιμες μετατροπές';
$strMIME_description = 'Περιγραφή';
$strMIME_nodescription = 'Δεν υπάρχει διαθέσιμη περιγραφή για αυτή τη μετατροπή.<br />Παρακαλώ απευθηνθείτε στον δημιουργό της για να μάθετε, τι κάνει η μετατροπή %s.';
$strMIME_transformation = 'Μετατροπή περιηγητή';
$strMIME_transformation_note = 'Για μία λίστα με τις διαθέσιμες μετατροπές και τις μετατροπές τύπου MIME, πατήστε %sπεριγραφές μετατροπών%s';
$strMIME_transformation_options = 'Επιλογές μετατροπής';
$strMIME_transformation_options_note = 'Παρακαλώ εισάγετε τις τιμές για τη μετατροπή χρησιμοποιώντας τη μορφή: \'a\',\'b\',\'c\'...<br />Εάν χρειαστείτε να χρησιμοποιήσετε καθέτους ("\") ή μονά εισαγωγικά ("\'") στις τιμές, χρησιμοποιείτε καθέτους (παράδειγμα \'\\\\xyz\' ή \'a\\\'b\').';
$strMIME_without = 'Οι τύποι MIME που εμφανίζονται με πλάγια γράμματα δεν έχουν ξεχωριστή λειτουργία μετατροπής';
$strModifications = 'Οι αλλαγές αποθηκεύτηκαν';
$strModify = 'Τροποποίηση';
$strModifyIndexTopic = 'Αλλαγή ενός ευρετηρίου';
$strMoreStatusVars = 'Περισσότερες μεταβλητές κατάστασης'; 
$strMoveTable = 'Μεταφορά πίνακα σε (βάση<b>.</b>πίνακας):';
$strMoveTableOK = 'Ο πίνακας %s μεταφέρθηκε στο %s.';
$strMoveTableSameNames = 'Δεν είναι δυνατή η μεταφορά του πίνακα στον εαυτό του!';  
$strMultilingual = 'πολυγλωσσικό';  
$strMustSelectFile = 'Πρέπει να επιλέξετε το αρχείο που θέλετε να εισάγετε.';  
$strMySQLCharset = 'Σετ χαρακτήρων της MySQL';  
$strMySQLReloaded = 'Η MySQL επαναφορτώθηκε.';
$strMySQLSaid = 'Η MySQL επέστρεψε το μύνημα: ';
$strMySQLServerProcess = 'Η MySQL %pma_s1% εκτελείται στον %pma_s2% ως %pma_s3%';
$strMySQLShowProcess = 'Εμφάνιση διεργασιών';
$strMySQLShowStatus = 'Εμφάνιση πληροφορών εκτέλεσης της MySQL';
$strMySQLShowVars = 'Εμφάνιση μεταβλητών της MySQL';

$strName = 'Όνομα';
$strNext = 'Επόμενο';
$strNo = 'Όχι';
$strNoDatabases = 'Δεν υπάρχουν βάσεις δεδομένων';
$strNoDatabasesSelected = 'Δεν έχετε επιλέξει βάσεις.';  
$strNoDescription = 'χωρίς περιγραφή';  
$strNoDropDatabases = 'Οι εντολές «DROP DATABASE» έχουν απενεργοποιηθεί.';
$strNoExplain = 'Χωρίς ανάλυση SQL';  
$strNoFrames = 'Το phpMyAdmin είναι πιο φιλικό με έναν browser <b>που υποστηρίζει frames</b>.';
$strNoIndex = 'Δεν ορίστηκε ευρετήριο!';
$strNoIndexPartsDefined = 'Δεν ορίστηκαν τα στοιχεία του ευρετηρίου!';
$strNoModification = 'Χωρίς αλλαγή';
$strNoOptions = 'Αυτή η μορφή δεν έχει επιλογές';
$strNoPassword = 'Χωρίς Κωδικό Πρόσβασης';
$strNoPermission = 'Ο διακομιστής δεν έχει δικαιώματα αποθήκευσης του αρχείου %s.';  
$strNoPhp = 'χωρίς κώδικα PHP';  
$strNoPrivileges = 'Χωρίς Προνόμια';
$strNoQuery = 'Δεν υπάρχει εντολή SQL!';
$strNoRights = 'Δεν έχετε αρκετά δικαιώματα να είσαστε εδώ τώρα!';
$strNoSpace = 'Δεν υπάρχει διαθέσιμος χώρος για την αποθήκευση του αρχείου %s.';  
$strNoTablesFound = 'Δεν βρέθηκαν Πίνακες στη βάση.';
$strNoUsersFound = 'Δεν βρέθηκαν χρήστες.';
$strNoValidateSQL = 'Skip Validate SQL';  
$strNone = 'Κανένα';
$strNotNumber = 'Αυτό δεν είναι αριθμός!';
$strNotOK = 'ΛΑΘΟΣ';
$strNotSet = 'Ο πίνακας <b>%s</b> δεν βρέθηκε ή δεν ορίστηκε στη %s';  
$strNotValidNumber = ' δεν είναι υπαρκτός αριθμός Εγγραφής!';
$strNull = 'Κενό';
$strNumSearchResultsInTable = '%s αποτελέσματα στον πίνακα <i>%s</i>';
$strNumSearchResultsTotal = '<b>Σύνολο:</b> <i>%s</i> αποτελέσματα';
$strNumTables = 'Πίνακες'; 

$strOK = 'OK';
$strOftenQuotation = 'Συχνά εισαγωγικά. Το OPTIONALLY σημαίνει ότι μόνο τα πεδία char και varchar εμπεριέχονται με τον χαρακτήρα «περιστοιχίζεται από».';
$strOperations = 'Λειτουργίες';  
$strOptimizeTable = 'Βελτιστοποίηση Πίνακα';
$strOptionalControls = 'Προεραιτικό. Ρυθμίζει πώς να γίνεται η ανάγνωση και η εγγραφή ειδικών χαρακτήρων.';
$strOptionally = 'ΠΡΟΑΙΡΕΤΙΚΑ';
$strOr = 'Ή';
$strOverhead = 'Επιβάρυνση';
$strOverwriteExisting = 'Αντικατάσταση υπαρχόντων αρχείων';  

$strPHP40203 = 'Χρησιμοποιείτε την PHP 4.2.3, η οποία είχε ένα σοβαρό πρόβλημα με αλφαριθμητικά τύπου multi-byte (mbstring). Δείτε το αναφορά προβλήματος PHP 19404. Αυτή η έκδοση της PHP δεν προτείνεται για χρήση με το phpMyAdmin.';  
$strPHPVersion = 'Έκδοση PHP';
$strPageNumber = 'Σελίδα:';  
$strPaperSize = 'Μέγεθος χαρτιού';  
$strPartialText = 'Επιμέρους κείμενα';
$strPassword = 'Κωδικός Πρόσβασης';
$strPasswordChanged = 'Ο Κωδικός Πρόσβασης για τον χρήστη %s άλλαξε επιτυχώς.'; 
$strPasswordEmpty = 'Ο Κωδικός Πρόσβασης είναι κενός!';
$strPasswordNotSame = 'Οι κωδικοί πρόσβασης δεν είναι ίδιοι!';
$strPdfDbSchema = 'Σχήμα της βάσης "%s" - Σελίδα %s';  
$strPdfInvalidTblName = 'Ο πίνακας "%s" δεν υπάρχει!';  
$strPdfNoTables = 'Δεν υπάρχουν πίνακες';
$strPerHour = 'ανά ώρα'; 
$strPerMinute = 'ανά λεπτό';
$strPerSecond = 'ανά δευτερόλεπτο';
$strPhoneBook = 'τηλ. κατάλογος';  
$strPhp = 'Δημιουργία κώδικα PHP';  
$strPmaDocumentation = 'Τεκμηρίωση phpMyAdmin';
$strPmaUriError = 'Η εντολή <tt>$cfg[\'PmaAbsoluteUri\']</tt> ΠΡΕΠΕΙ να οριστεί στο αρχείο ρυθμίσεων!';
$strPortrait = 'Κάθετη διάταξη';  
$strPos1 = 'Αρχή';
$strPrevious = 'Προηγούμενο';
$strPrimary = 'Πρωτεύον';
$strPrimaryKeyHasBeenDropped = 'Το πρωτεύον κλειδί διεγράφη';
$strPrimaryKeyName = 'Το όνομα του πρωτεύοντος κλειδιού πρέπει να είναι... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>πρέπει</b> να είναι το όνομα του πρωτεύοντος κλειδιού και <b>μόνο αυτού</b> !)';
$strPrint = 'Εκτύπωση';  
$strPrintView = 'Εμφάνιση για εκτύπωση';
$strPrivDescAllPrivileges = 'Περιλαμβάνει όλα τα προνόμια εκτός από το GRANT.'; 
$strPrivDescAlter = 'Επιτρέπει την αλλαγή δομής των υπαρχόντων πινάκων.'; 
$strPrivDescCreateDb = 'Επιτρέπει τη δημιουργία νέων βάσεων και πινάκων.'; 
$strPrivDescCreateTbl = 'Επιτρέπει τη δημιουργία νέων πινάκων.'; 
$strPrivDescCreateTmpTable = 'Επιτρέπει τη δημιουργία προσωρινών πινάκων.'; 
$strPrivDescDelete = 'Επιτρέπει τη διαγραφή δεδομένων.'; 
$strPrivDescDropDb = 'Επιτρέπει τη διαγραφή βάσεων και πινάκων.'; 
$strPrivDescDropTbl = 'Επιτρέπει τη διαγραφή πινάκων.'; 
$strPrivDescExecute = 'Επιτρέπει την εκτέλεση αποθηκευμένων ρουτινών. Δεν έχει χρήση σε αυτήν την έκδοση MySQL version.'; 
$strPrivDescFile = 'Επιτρέπει την εισαγωγή και εξαγωγή δεδομένων από και σε αρχεία.'; 
$strPrivDescGrant = 'Επιτρέπει την προσθήκη χρηστών και προνομίων χωρίς να επαναφορτώσετε τους πίνακες προνομίων.'; 
$strPrivDescIndex = 'Επιτρέπει την δημιουργία και την διαγραφή ευρετηρίων.'; 
$strPrivDescInsert = 'Επιτρέπει την εισαγωγή και την αντικατάσταση δεδομένων.'; 
$strPrivDescLockTables = 'Επιτρέπει το κλείδωμα πινάκων για την τρέχουσα λειτουργία.'; 
$strPrivDescMaxConnections = 'Περιορίζει τον αριθμό των νέων συνδέσεων που ο χρήστης μπορεί να ξεκινήσει ανά ώρα.';
$strPrivDescMaxQuestions = 'Περιορίζει τον αριθμό των επερωτημάτων που ο χρήστης μπορεί να στείλει στον διακομιστή ανά ώρα.';
$strPrivDescMaxUpdates = 'Περιορίζει τον αριθμό των αλλαγής πινάκων ή βάσεων που ο χρήστης μπορεί να εκετελέσει ανά ώρα.';
$strPrivDescProcess3 = 'Επιτρέπει την διακοπή διεργασιών άλλων χρηστών.'; 
$strPrivDescProcess4 = 'Επιτρέπει την εμφάνιση ολοκληρωμένων επερωτημάτων στη λίστα διεργασιών.'; 
$strPrivDescReferences = 'Δεν έχει χρήση σε αυτήν την έκδοση MySQL.'; 
$strPrivDescReload = 'Επιτρέπει την επανεκκίνηση του διακομιστή και τον καθαρισμό των προσωρινών αρχείων του.'; 
$strPrivDescReplClient = 'Δίνει το δικαίωμα στον χρήστη να βρει που είναι οι κύριοι και δευτερεύοντες διακομιστές.'; 
$strPrivDescReplSlave = 'Απαιτείται για τους δευτερευόντες διακομιστές αναπαραγωγής.'; 
$strPrivDescSelect = 'Επιτρέπει την ανάγνωση δεδομένων.'; 
$strPrivDescShowDb = 'Δίνει πρόσβαση στην πλήρη λίστα των βάσεων δεδομένων.'; 
$strPrivDescShutdown = 'Επιτρέπει την διακοπή λειτουργίας του διακομιστή.'; 
$strPrivDescSuper = 'Επιτρέπει τη σύνδεση, ακόμα και όταν ο μέγιστος αριθμός συνδέσεων έχει καλυθφεί; Απαιτείται για τις περισσότερες λειτουργίες διαχείρισης όπως ο ορισμός γενικών μεταβλητών ή τη διακοπή λειτουργιών άλλων χρηστών.'; 
$strPrivDescUpdate = 'Επιτρέπει την αλλαγή δεδομένων.'; 
$strPrivDescUsage = 'Χωρίς προνόμια.'; 
$strPrivileges = 'Προνόμια';
$strPrivilegesReloaded = 'Τα προνόμια επαναφορτώθηκαν επιτυχώς.'; 
$strProcesslist = 'Λίστα διεργασιών'; 
$strPutColNames = 'Εμφάνιση ονομάτων πεδίων στην πρώτη γραμμή';  

$strQBE = 'Επερώτημα κατά παράδειγμα';
$strQBEDel = 'Διαγραφή';
$strQBEIns = 'Εισαγωγή';
$strQueryFrame = 'Παράθυρο επερωτήματος';
$strQueryOnDb = 'Εντολή SQL στη βάση <b>%s</b>:';
$strQuerySQLHistory = 'Ιστορικό SQL';
$strQueryStatistics = '<b>Στατιστικά επερωτημάτων</b>: Από την έναρξη λειτουργίας, %s επερωτήματα έχουν σταλεί στον διακομιστή.';
$strQueryTime = 'Το επερώτημα χρειάστηκε %01.4f δευτ/τα';
$strQueryType = 'Τύπος επερωτήματος'; 
$strQueryWindowLock = 'Να μην αλλάξει το επερώτημα από εξωτερική πηγή';  

$strReType = 'Επαναεισαγωγή';
$strReceived = 'Λήφθησαν'; 
$strRecords = 'Εγγραφές';
$strReferentialIntegrity = 'Έλεγχος ακεραιότητας σχέσεων:';
$strRelationNotWorking = 'Οι επιπρόσθετες λειτουργίες για εργασία με συσχετισμένους πίνακες έχουν απενεργοποιηθεί. Για να μάθετε γιατί, πατήστε %sεδώ%s.';
$strRelationView = 'Εμφάνιση σχέσεων';  
$strRelationalSchema = 'Σχεσιακό σχήμα';  
$strRelations = 'Σχέσεις';  
$strReloadFailed = 'Η επανεκκίνηση της MySQL απέτυχε.';
$strReloadMySQL = 'Επανεκκίνηση της MySQL';
$strReloadingThePrivileges = 'Επαναφόρτωση προνομίων'; 
$strRemoveSelectedUsers = 'Διαγραφή των επιλεγμένων χρηστών'; 
$strRenameTable = 'Μετονομασία πίνακα σε';
$strRenameTableOK = 'Ο Πίνακας %s μετονομάσθηκε σε %s';
$strRepairTable = 'Επιδιόρθωση πίνακα';
$strReplace = 'Αντικατάσταση';
$strReplaceNULLBy = 'Αντικατάσταση τιμής NULL με';  
$strReplaceTable = 'Αντικατάσταση δεδομένων Πίνακα με το αρχείο';
$strReset = 'Επαναφορά';
$strResourceLimits = 'Όρια πόρων'; 
$strRevoke = 'Ανάκληση';
$strRevokeAndDelete = 'Ανάκληση όλων των ενεργών προνομίων από τους χρήστες και διαγραφή τους.'; 
$strRevokeAndDeleteDescr = 'Οι χρήστες θα συνεχίσουν να έχουν το προνόμιο USAGE μέχρις ότου επαναφορτωθούν τα προνόμια.'; 
$strRevokeMessage = 'Ανακαλέσατε τα προνόμια για %s';
$strRowLength = 'Μέγεθος Γραμμής';
$strRowSize = ' Μέγεθος Εγγραφής ';
$strRows = 'Εγγραφές';
$strRowsFrom = 'Εγγραφές αρχίζοντας από την εγγραφή';
$strRowsModeFlippedHorizontal = 'οριζόντια (στραμμένες επικεφαλίδες)';
$strRowsModeHorizontal = 'οριζόντια';
$strRowsModeOptions = 'σε %s μορφή με επανάληψη επικεφαλίδων ανά %s κελιά';
$strRowsModeVertical = 'κάθετη';
$strRowsStatistic = 'Στατιστικά Εγγραφών';
$strRunQuery = 'Υποβολή επερωτήματος';
$strRunSQLQuery = 'Εκτέλεση εντολής/εντολών SQL στη βάση δεδομένων %s';
$strRunning = 'που εκτελείται στο %s';
$strRussian = 'Ρωσσικά';  

$strSQL = 'SQL'; 
$strSQLOptions = 'Επιλογές SQL';
$strSQLParserBugMessage = 'Υπάρχει περίπτωση να εντοπίσατε ένα πρόβλημα στον SQL parser. Παρακαλώ εξετάστε το επερώτημά σας προσεκτικά και ελέγξτε ότι όλα τα εισαγωγικά ανοίγουν και κλείνουν σωστά. \'Αλλες πιθανές αιτίες μπορούν να είναι η αποστολή αρχείου με δυαδικό κώδικα εκτός εισαγωγικών. Μπορείτε επίσης να δοκιμάσετε το επερώτημά σας στη γραμμή εντολών της MySQL.  Εάν συνεχίζετε να έχετε πρόβλημα, ή εάν ο parser αποτυγχάνει όπου η γραμμή εντολών επιτυγχάνει, παρακαλώ απομονώστε το επερώτημα εκείνο που δημιουργεί το πρόβλημα και στείλτε αναφορά λάθους με τα δεδομένα που βρίσκονται στο τμήμα CUT που ακολουθεί:';  
$strSQLParserUserError = 'Φαίνεται να υπάρχει ένα λάθος στο επερώτημά σας. Το κάτωθι λάθος διακομιστή MySQL, εάν υπάρχει κάποιο, μπορεί επίσης να σας βοηθήσει να διαγνώσετε το πρόβλημα.';
$strSQLQuery = 'Εντολή SQL';
$strSQLResult = 'αποτέλεσμα SQL'; 
$strSQPBugInvalidIdentifer = '\'Αγνωστο Αναγνωριστικό';  
$strSQPBugUnclosedQuote = 'Ανοιχτά εισαγωγικά';  
$strSQPBugUnknownPunctuation = '\'Αγνωστο σημείο στίξης';  
$strSave = 'Αποθήκευση';
$strSaveOnServer = 'Αποθήκευση στον διακομιστή στον φάκελο %s';  
$strScaleFactorSmall = 'Η κλίμακα είναι πολύ μικρή για να εμφανιστεί το σχήμα σε μία σελίδα';  
$strSearch = 'Αναζήτηση';
$strSearchFormTitle = 'Αναζήτηση στη βάση';
$strSearchInTables = 'Μέσα στους πίνακες:';
$strSearchNeedle = 'Όροι ή τιμές για αναζήτηση (μπαλαντέρ: "%"):';
$strSearchOption1 = 'τουλάχιστον έναν από τους όρους';
$strSearchOption2 = 'όλους τους όρους';
$strSearchOption3 = 'την ακριβή φράση';
$strSearchOption4 = 'ως regular expression';
$strSearchResultsFor = 'Αποτελέσματα αναζήτησης για "<i>%s</i>" %s:';
$strSearchType = 'Έυρεση:';
$strSecretRequired = 'Το αρχείο ρυθμίσεων χρειάζεται τώρα μία μυστική φράση-κλειδί (blowfish_secret).';  
$strSelectADb = 'Παρακαλώ επιλέξτε μία βάση δεδομένων';
$strSelectAll = 'Επιλογή όλων';
$strSelectFields = 'Επιλογή πεδίων (τουλάχιστον ένα)';
$strSelectNumRows = 'στην εντολή';
$strSelectTables = 'Επιλογή Πινάκων';  
$strSend = 'Αποστολή';
$strSent = 'Εστάλησαν'; 
$strServer = 'Διακομιστής';  
$strServerChoice = 'Επιλογή Διακομιστή';
$strServerStatus = 'Πληροφορίες εκτέλεσης'; 
$strServerStatusUptime = 'Αυτός ο διακομιστής MySQL λειτουργεί για %s. Ξεκίνησε στις %s.'; 
$strServerTabProcesslist = 'Διεργασίες'; 
$strServerTabVariables = 'Μεταβλητές'; 
$strServerTrafficNotes = '<b>Κίνηση Διακομιστή</b>: Αυτοί οι πίνακες δείχνουν στατιστικά χρήσης δικτύου αυτού του διακομιστή MySQL από την έναρξη της λειτουργίας του.';
$strServerVars = 'Ρυθμίσεις και μεταβλητές του διακομιστή'; 
$strServerVersion = 'Έκδοση Διακομιστή';
$strSessionValue = 'Τιμή Session'; 
$strSetEnumVal = 'Αν ο τύπος του πεδίου είναι «enum» ή «set», παρακαλώ εισάγετε τις τιμές χρησιμοποιώντας την εξής μορφή: \'α\',\'β\',\'γ\'...<br /> Αν χρειάζεται να εισάγετε την ανάποδη κάθετο ("\") ή απλά εισαγωγικά ("\'"), προθέστε τα με ανάποδη κάθετο στην αρχή (για παράδειγμα \'\\\\χψω\' ή \'α\\\'β\').';
$strShow = 'Εμφάνιση';
$strShowAll = 'Εμφάνιση όλων';
$strShowColor = 'Εμφάνιση χρωμάτων';  
$strShowDatadictAs = 'Μορφή λεξικού δεδομένων';  
$strShowFullQueries = 'Πλήρης εμφάνιση επερωτημάτων';  
$strShowGrid = 'Εμφάνιση πλέγματος';  
$strShowPHPInfo = 'Εμφάνιση πληροφοριών της PHP';
$strShowTableDimension = 'Εμφάνιση διαστάσεων πινάκων';  
$strShowTables = 'Εμφάνιση πινάκων';
$strShowThisQuery = ' Εμφάνισε εδώ ξανά αυτό το επερώτημα';
$strShowingRecords = 'Εμφάνιση εγγραφής ';
$strSimplifiedChinese = 'Απλοποιημένα Κινεζικά';  
$strSingly = '(μοναδικά)';
$strSize = 'Μέγεθος';
$strSort = 'Ταξινόμηση';
$strSpaceUsage = 'Χρήση χώρου';
$strSplitWordsWithSpace = 'Οι λέξεις χωρίζονται από τον χαρακτήρα διαστήματος (" ").';
$strStatCheckTime = 'τελευταίος έλεγχος';
$strStatCreateTime = 'Δημιουργία';
$strStatUpdateTime = 'Τελευταία ενημέρωση';
$strStatement = 'Δηλώσεις';
$strStatus = 'Κατάσταση'; 
$strStrucCSV = 'Δεδομένα CSV';
$strStrucData = 'Δομή και δεδομένα';
$strStrucDrop = 'Προσθήκη «Drop Table»';
$strStrucExcelCSV = 'Μορφή CSV για δεδομένα MS Excel';
$strStrucOnly = 'Μόνο η δομή';
$strStructPropose = 'Προτεινόμενη δομή πίνακα';  
$strStructure = 'Δομή';  
$strSubmit = 'Αποστολή';
$strSuccess = 'Η SQL εντολή σας εκτελέσθηκε επιτυχώς';
$strSum = 'Σύνολο';
$strSwedish = 'Σουηδικά';  
$strSwitchToTable = 'Μεταφορά στον αντεγραμμένο πίνακα';  

$strTable = 'Πίνακας ';
$strTableComments = 'Σχόλια Πίνακα';
$strTableEmpty = 'Το όνομα του Πίνακα είναι κενό!';
$strTableHasBeenDropped = 'Ο Πίνακας %s διεγράφη';
$strTableHasBeenEmptied = 'Ο Πίνακας %s άδειασε';
$strTableHasBeenFlushed = 'Ο Πίνακας %s εκκαθαρίστικε ("FLUSH")';
$strTableMaintenance = 'Συντήρηση Πίνακα';
$strTableOfContents = 'Πίνακας περιεχομένων';  
$strTableOptions = 'Επιλογές πίνακα';  
$strTableStructure = 'Δομή Πίνακα για τον Πίνακα';
$strTableType = 'Τύπος Πίνακα';
$strTables = '%s Πίνακας/Πίνακες';
$strTblPrivileges = 'Προνόμια πινάκων'; 
$strTextAreaLength = ' Εξαιτίας του μεγέθος του,<br /> αυτό το πεδίο ίσως να μη μπορεί να διορθωθεί ';
$strThai = 'Ταϋλανδικά';  
$strTheContent = 'Τα περιεχόμενα του αρχείου σας έχουν εισαχθεί.';
$strTheContents = 'Τα περιεχόμενα του αρχείου αντικαθιστούν τα περιεχόμενα του επιλεγμένου πίνακα για Γραμμές με ίδιο πρωτεύον ή μοναδικό κλειδί.';
$strTheTerminator = 'Ο τερματικός χαρακτήρας των πεδίων.';
$strThisHost = 'Αυτός ο διακομιστής'; 
$strThisNotDirectory = 'Δεν ήταν φάκελος';  
$strThreadSuccessfullyKilled = 'Η λειτουργία %s διεκόπη.'; 
$strTime = 'Χρόνος'; 
$strToggleScratchboard = '(Απ)ενεργοποίηση πίνακα σχεδιασμού';  
$strTotal = 'συνολικά';
$strTotalUC = 'Σύνολο'; 
$strTraditionalChinese = 'Παραδοσιακά Κινεζικά';  
$strTraffic = 'Κίνηση'; 
$strTransformation_image_jpeg__inline = 'Εμφανίζει μια εικόνα προεπισκόπησης με σύνδεσμο; επιλογές: πλάτος, ύψος σε pixels (διατηρεί τις αρχικές αναλογίες)';
$strTransformation_image_jpeg__link = 'Εμφανίζει έναν σύνδεσμο για αυτήν την εικόνα.';
$strTransformation_image_png__inline = 'Δείτε image/jpeg: inline';  
$strTransformation_text_plain__dateformat = 'Παίρνει ένα πεδίο TIME, TIMESTAMP ή DATETIME και το μορφοποιεί χρησιμοποιώντας την τοπική μορφή. Η πρώτη επιλογή είναι η διαφορά (σε ώρες) που θα προστεθεί στην ώρα (Εξ\' ορισμού: 0). Η δεύτερη επιλογή είναι μορφή ημερομηνίας όπως ορίζεται από τις διαθέσιμες παραμέτρους της εντολής strftime() της PHP.';
$strTransformation_text_plain__external = 'ΜΟΝΟ ΓΙΑ LINUX: Εκτελεί μία εξωτερική εφαρμογή και στέλνει τα δεδομένα μέσω \'standard input\'. Επιστρέφει το αποτέλεσμα της εφαρμογής. Εξ\' ορισμού τιμή είναι το Tidy, που τυπώνει μορφοποιημένο κώδικα HTML. Για λόγους ασφαλείες, πρέπει χειροκίνητα να αλλάξετε το αρχείο libraries/transformations/text_plain__external.inc.php και να εισάγετε τις εφαρμογές που εσείς επιτρέπετε να εκτελούνται. Η πρώτη επιλογή είναι ο αριθμός της εφαρμογής που θέλετε να χρησιμοποιήσετε και η δεύτερη επιλογή είναι οι παράμετροι της. Η τρίτη επιλογή, αν τεθεί σε 1 θα μετατρέψει το αποτέλεσμα χρησιμοποιώντας την εντολή htmlspecialchars() (Εξ\' ορισμού τιμή: 1). Η τέταρτη επιλογή, αν τεθεί σε 1 θα εισάγει NOWRAP στο κελί περιεχομένου ούτως ώστε όλο το αποτέλεσμα να εμφανιστεί χωρίς αλλαγές στην διάταξη (Εξ\' ορισμού τιμή: 1)';
$strTransformation_text_plain__formatted = 'Διατηρεί την αρχική μορφοποίηση του πεδίου. Δεν χρησιμοποιούνται χαρακτήρες διαφυγής.';
$strTransformation_text_plain__imagelink = 'Εμφανίζει μία εικόνα και ένα σύνδεσμο, το πεδίο περιέχει το όνομα αρχείου. Η πρώτη επιλογή είναι ένα πρόθεμα όπως "http://domain.com/", η δεύτερη επιλογή είναι το πλάτος σε pixels, η τρίτη είναι το ύψος.';  
$strTransformation_text_plain__link = 'Εμφανίζει ένα σύνδεσμο, το πεδίο περιέχει το όνομα αρχείου. Η πρώτη επιλογή είναι ένα πρόθεμα όπως "http://domain.com/", η δεύτερη επιλογή είναι ένας τίτλος για τον σύνδεσμο.';  
$strTransformation_text_plain__substr = 'Εμφανίζει μόνο μέρος ενός αλφαριθμητικού. Η πρώτη επιλογή είναι η θέση στην οποία ξεκινά η εμφάνιση του κειμένου (Εξ\' ορισμού 0). Η δεύτερη επιλογή είναι το μήκος του κειμένου. Αν μείνει κενό θα επιστραφεί όλο το αλφαριθμητικό. Η τρίτη επιλογή καθορίζει ποιοι χαρακτήρες θα ακολουθούν το κείμενο όταν εμφανίζεται μέρος του (Εξ\' ορισμού: ...) .';
$strTruncateQueries = 'Αποκοπή εμφανιζόμενων επερωτημάτων';  
$strTurkish = 'Τουρκικά';  
$strType = 'Τύπος';

$strUkrainian = 'Ουκρανικά';  
$strUncheckAll = 'Απεπιλογή όλων';
$strUnicode = 'Unicode';  
$strUnique = 'Μοναδικό';
$strUnknown = 'άγνωστο';  
$strUnselectAll = 'Απεπιλογή όλων';
$strUpdComTab = 'Παρακαλώ διαβάστε στην τεκμηρίωση για το πως μπορείτε να ανανεώσετε τον πίνακα Column_comments';  
$strUpdatePrivMessage = 'Τα προνόμια του χρήστη %s ενημερώθηκαν.';
$strUpdateProfileMessage = 'Τα στοιχεία ανανεώθηκαν.';
$strUpdateQuery = 'Ενημέρωση της εντολής';
$strUsage = 'Χρήση';
$strUseBackquotes = 'Χρήση ανάποδων εισαγωγικών στα ονόματα των Πινάκων και των Πεδίων';
$strUseHostTable = 'Use Host Table';  
$strUseTables = 'Χρήση Πινάκων';
$strUseTextField = 'Χρησιμοποιήστε το πεδίο κειμένου'; 
$strUseThisValue = 'Χρήση αυτής της τιμής';  
$strUser = 'Χρήστης';
$strUserAlreadyExists = 'Ο χρήστης %s υπάρχει ήδη!'; 
$strUserEmpty = 'Το όνομα του χρήστη είναι κενό!';
$strUserName = 'Όνομα χρήστη';
$strUserNotFound = 'Ο επιλεγμένος χρήστης δεν βρέθηκε στον πίνακα προνομίων.'; 
$strUserOverview = 'Περίληψη χρηστών'; 
$strUsersDeleted = 'Οι επιλεγμένοι χρήστες διεγράφησαν επιτυχώς.'; 
$strUsersHavingAccessToDb = 'Χρήστες με πρόσβαση στη βάση &quot;%s&quot;';  

$strValidateSQL = 'Επικύρωση SQL';  
$strValidatorError = 'Ο επικυρωτής SQL δεν μπόρεσε να ενεργοποιηθεί. Παρακαλώ ελέγξτε ότι έχετε εγκαταστήσει της απαραίτητες επεκτάσεις της php όπως περιγράφεται στην %sdocumentation%s.'; 
$strValue = 'Τιμή';
$strVar = 'Μεταβλητή'; 
$strViewDump = 'Εμφάνιση σχήματος του πίνακα';
$strViewDumpDB = 'Εμφάνιση σχήματος της βάσης';
$strViewDumpDatabases = 'Εμφάνισης σχήματος βάσεων';

$strWebServerUploadDirectory = 'Υποκατάλογος αποθήκευσης αρχείων διακομιστή';  
$strWebServerUploadDirectoryError = 'Ο υποκατάλογος που ορίσατε για την αποθήκευση αρχείων δεν μπόρεσε να βρεθεί';  
$strWelcome = 'Καλωσήρθατε στο %s';
$strWestEuropean = 'Δυτικής Ευρώπης';  
$strWildcard = 'μπαλαντέρ';  
$strWindowNotFound = 'Δεν ήταν δυνατό να ανανεωθεί το target παράθυρο του περιηγητή. Ίσως κλείσατε το parent παράθυρο ή ο περιηγητής σας δεν επιτρέπει τις ανανεώσεις μεταξύ παραθύρων λόγω ρυθμίσεων ασφαλείας.';  
$strWithChecked = 'Με τους επιλεγμένους:';
$strWritingCommentNotPossible = 'Η εγγραφή του σχολίου δεν ήταν δυνατή';  
$strWritingRelationNotPossible = 'Η εγγραφή της σχέσης δεν ήταν δυνατή';  
$strWrongUser = 'Λανθασμένο όνομα χρήστη/κωδικός πρόσβασης. \'Αρνηση πρόσβασης.';

$strXML = 'XML';

$strYes = 'Ναι';

$strZeroRemovesTheLimit = 'Σημείωση: Αν ορίσετε αυτές τις επιλογές σε 0 (μηδέν) αφαιρείτε ο περιορισμός.'; 
$strZip = 'συμπίεση «zip»';
// To Translate

$strBrowseForeignValues = 'Browse foreign values';  //to translate

$strCaseInsensitive = 'case-insensitive';  //to translate
$strCaseSensitive = 'case-sensitive';  //to translate
$strCharsetsAndCollations = 'Character Sets and Collations';  //to translate
$strCollation = 'Collation';  //to translate

$strInternalRelations = 'Internal relations';  //to translate
$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';  //to translate
$strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
$strLatexStructure = 'Structure of table __TABLE__';//to translate
$strLatexContinued = '(continued)';//to translate
$strLatexContent = 'Content of table __TABLE__';//to translate
$strLatexIncludeCaption = 'Include table caption';//to translate
$strLatexCaption = 'Table caption';//to translate
$strLatexLabel = 'Label key';//to translate
$strLatexContinuedCaption = 'Continued table caption';//to translate

$strPrintViewFull = 'Print view (with full texts)';  //to translate
$strLogServer = 'Server';  //to translate
$strSortByKey = 'Sort by key';  //to translate
$strBookmarkAllUsers = 'Let every user access this bookmark';  //to translate
$strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
$strConstraintsForTable = 'Constraints for table';  //to translate
$strBookmarkOptions = 'Bookmark options';  //to translate
$strCreationDates = 'Creation/Update/Check dates';  //to translate
$strCheckOverhead = 'Check tables with overhead';  //to translate
$strExcelEdition = 'Excel edition';  //to translate
$strDelayedInserts = 'Use delayed inserts';  //to translate
$strSQLExportType = 'Export type';  //to translate
$strAddConstraints = 'Add constraints';  //to translate
$strGeorgian = 'Georgian';  //to translate
$strCzechSlovak = 'Czech-Slovak';  //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strMaximumSize = 'Maximum size: %s%s';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDBRename = 'Rename database to';  //to translate
$strOperator = 'Operator';  //to translate
$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strCalendar = 'Calendar';  //to translate
$strRefresh = 'Refresh';  //to translate
$strDefragment = 'Defragment table';  //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strSpanish = 'Spanish';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strTheme = 'Theme / Style';  //to translate
$strTakeIt = 'take it';  //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strIcelandic = 'Icelandic';  //to translate
$strLatvian = 'Latvian';  //to translate
$strPolish = 'Polish';  //to translate
$strRomanian = 'Romanian';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strSlovak = 'Slovak';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
?>
